@@ -77,8 +77,8 @@ nameday_desktop_applet_on_show_settings (GtkWidget *widget,
 }
 
 static void
-nameday_desktop_applet_on_button_press_event (GtkWidget *widget,
-					      gpointer data)
+nameday_desktop_applet_on_button_release_event (GtkWidget *widget,
+						gpointer data)
 {
 	NamedayDesktopApplet *priv = NAMEDAY_DESKTOP_APPLET (widget);
 
@@ -89,6 +89,36 @@ nameday_desktop_applet_on_button_press_event (GtkWidget *widget,
 
 	if (!priv->calendar_window) {
 		priv->calendar_window = nameday_calendar_window_create (priv);
+	} else {
+		gtk_window_present (GTK_WINDOW (priv->calendar_window));
+	}
+}
+
+static void
+nameday_desktop_applet_on_current_desktop (GtkWidget *widget,
+					   gpointer data)
+{
+	NamedayDesktopApplet *priv = NAMEDAY_DESKTOP_APPLET (widget);
+	gboolean on;
+
+	g_return_if_fail (priv);
+
+	g_object_get (widget, "is-on-current-desktop", &on, NULL);
+	if (!on) {
+		/* Remove the timeout handler */
+		if (priv->timeout_handler) {
+			g_source_remove (priv->timeout_handler);
+			priv->timeout_handler = -1;
+		}
+	} else {
+		/* force update desktop applet */
+		nameday_desktop_applet_on_timeout (priv);
+
+		/* Add the timeout handler */
+		if (!priv->timeout_handler) {
+			priv->timeout_handler = g_timeout_add (60000, nameday_desktop_applet_on_timeout,
+							       priv);
+		}
 	}
 }
 
@@ -220,9 +250,10 @@ nameday_desktop_applet_finalize (GObject *object)
 	nameday_dbparser_finalize (priv);
 	nameday_settings_finalize (priv);
 
-	/* Remove the timout handler: */
+	/* Remove the timeout handler */
 	if (priv->timeout_handler) {
 		g_source_remove (priv->timeout_handler);
+		priv->timeout_handler = 0;
 	}
 
 	/* Call the base class's implementation: */
@@ -234,6 +265,8 @@ nameday_desktop_applet_init (NamedayDesktopApplet *priv)
 {
 	GtkWidget *widget, *picker;
 
+	priv->timeout_handler = 0;
+
 	nameday_settings_init (priv);
 	nameday_dbparser_init (priv);
 
@@ -272,7 +305,8 @@ nameday_desktop_applet_init (NamedayDesktopApplet *priv)
 	hd_home_plugin_item_set_settings (HD_HOME_PLUGIN_ITEM (priv), TRUE);
 
 	g_signal_connect (priv, "show-settings", G_CALLBACK (nameday_desktop_applet_on_show_settings), NULL);
-	g_signal_connect (priv, "button_press_event", G_CALLBACK(nameday_desktop_applet_on_button_press_event), NULL);
+	g_signal_connect (priv, "button-release-event", G_CALLBACK (nameday_desktop_applet_on_button_release_event), NULL);
+	g_signal_connect (priv, "notify::is-on-current-desktop", G_CALLBACK (nameday_desktop_applet_on_current_desktop), NULL);
 }
 
 static void
