@@ -139,7 +139,10 @@ nameday_dbparser_liststore_create (NamedayDesktopApplet *priv)
 		return NULL;
 	}
 
-	list_store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_STRING);
+	list_store = gtk_list_store_new (4, G_TYPE_INT,		/* day */
+					    G_TYPE_INT,		/* month */
+					    G_TYPE_STRING,	/* date */
+					    G_TYPE_STRING);	/* name */
 
 	for (entry = root->children; entry != NULL; entry = entry->next)
 	{
@@ -158,6 +161,8 @@ nameday_dbparser_liststore_create (NamedayDesktopApplet *priv)
 			gtk_list_store_append (list_store, &iter);
 			gtk_list_store_set (list_store,
 					    &iter,
+					    COLUMN_DAY, atoi ((const gchar *)day),
+					    COLUMN_MONTH, atoi ((const gchar *)month),
 					    COLUMN_DATE, date,
 					    COLUMN_NAME, name,
 					    -1);
